@@ -3,20 +3,23 @@ var db = require('mime-db')
 var compressible = require('../')
 
 // None of these should be actual types so that the lookup will never include them.
-var example_types = [
+var EXAMPLE_TYPES = [
   { type: 'text/penguins', should: true },
-  { type: 'something/text', should: false },
+  { type: 'text/html', should: true },
+  { type: 'text/plain', should: true },
+  { type: 'text/jade', should: true },
+  { type: 'something/text', should: undefined },
   { type: 'something/frog+TEXT', should: true },
-  { type: 'type/json;askjkl+json', should: false },
+  { type: 'type/json;askjkl+json', should: undefined },
   { type: 'type/+json', should: true },
   { type: 'data/beans+xml ; charset="utf-8"', should: true },
   { type: 'can/worms+xml;blaaaah', should: true },
-  { type: 'data/xml', should: false },
-  { type: 'asdf/nope', should: false },
-  { type: 'cats', should: false }
+  { type: 'data/xml', should: undefined },
+  { type: 'asdf/nope', should: undefined },
+  { type: 'cats', should: undefined }
 ]
 
-var invalid_types = [
+var INVALID_TYPES = [
   undefined,
   null,
   0,
@@ -28,16 +31,17 @@ var invalid_types = [
 describe('Testing if spec lookups are correct.', function () {
   it('All DB `compressible` types should reflect in compressible', function () {
     for (var type in db) {
-      var value = db[type].compressible
-      assert.equal(compressible(type), value)
+      if (db[type].compressible !== undefined) {
+        assert.strictEqual(compressible(type), db[type].compressible)
+      }
     }
   })
 })
 
 describe('Testing if the regex works as intended.', function () {
-  example_types.forEach(function (example) {
+  EXAMPLE_TYPES.forEach(function (example) {
     it(example.type + ' should' + (example.should ? ' ' : ' not ') + 'be compressible', function () {
-      assert.equal(compressible(example.type), example.should)
+      assert.strictEqual(compressible(example.type), example.should)
     })
   })
 })
@@ -45,21 +49,22 @@ describe('Testing if the regex works as intended.', function () {
 describe('Testing if charsets are handled correctly.', function () {
   it('Charsets should be stripped off without issue', function () {
     for (var type in db) {
-      var value = db[type].compressible
-      assert.equal(compressible(type + '; charset=utf-8'), value)
+      if (db[type].compressible !== undefined) {
+        assert.strictEqual(compressible(type + '; charset=utf-8'), db[type].compressible)
+      }
     }
   })
 })
 
 describe('Ensuring invalid types do not cause errors.', function () {
   it('No arguments should return false without error', function () {
-    assert.equal(compressible(), false)
+    assert.strictEqual(compressible(), false)
   })
 
-  invalid_types.forEach(function (invalid) {
+  INVALID_TYPES.forEach(function (invalid) {
     it(invalid + ' should return false without error', function () {
       assert.doesNotThrow(function () {
-        assert.equal(compressible(invalid), false)
+        assert.strictEqual(compressible(invalid), false)
       })
     })
   })
@@ -67,11 +72,11 @@ describe('Ensuring invalid types do not cause errors.', function () {
 
 describe('Ensuring types are always stripped correctly.', function () {
   it('Uppercase types should work', function () {
-    assert.equal(compressible('TEXT/HTML'), true)
-    assert.equal(compressible('TEXT/plain; charset="utf-8"'), true)
+    assert.strictEqual(compressible('TEXT/HTML'), true)
+    assert.strictEqual(compressible('TEXT/plain; charset="utf-8"'), true)
   })
 
   it('White-spaced types should work', function () {
-    assert.equal(compressible('application/json ; charset="utf-8"'), true)
+    assert.strictEqual(compressible('application/json ; charset="utf-8"'), true)
   })
 })
